<?php

namespace Rtg\RtgTtaddressExtend\Domain\Repository;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

/**
 * The repository for the domain model Address
 *
 */
class AddressRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {

	/**
	 * Initialize repository object
	 *
	 * @return void
	 */
	public function initializeObject() {

		/** @var $querySettings \TYPO3\CMS\Extbase\Persistence\Generic\Typo3QuerySettings */
		$querySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');
		$querySettings->setRespectStoragePage(FALSE);
		$this->setDefaultQuerySettings($querySettings);
	}

	/**
	 * Get address by pid
	 *
	 * @param int
	 * @return object
	 */
	public function findByPid($pid) {

		$query = $this->createQuery();

		// Set storade pid
		if(intval($pid)) {
			$query->getQuerySettings()
				->setRespectStoragePage(TRUE)
				->setStoragePageIds(array(intval($pid)));
		}
			
		return $query->execute();
	}
	
	/**
	 * Get addresses by uids comma separated list
	 *
	 * @param string
	 * @return object
	 */
	public function findByUids($uids) {

		$query = $this->createQuery();

		$list = \TYPO3\CMS\Core\Utility\GeneralUtility::trimExplode(',', $uids, 1);
		if(is_array($list) AND count($list)) {
			$query->matching($query->in('uid', $list));
			return $query->execute();
		}
		return FALSE;
	}

	public function findAllGeoCenter() {

		$sql = '
			SELECT AVG(latitude) AS latitude, AVG(longitude) AS longitude
			FROM `tt_address`
			WHERE deleted = 0 AND hidden = 0 AND latitude > 0.0 AND longitude > 0.0
		';

		return $this->createQuery()
			->statement($sql)
			->execute();
	}
}
