/**
 * Handles geocoding and displays google maps with given locations;
 * Updated by Robert G.
 *
 * @package				class.gmaps
 * @version				1.0: gmaps,  03-2011
 * @copyright 			(c)2011 Christian Brinkert
 * @author 				Christian Brinkert <christian.brinkert@googlemail.com>
 */

/**
 * Try to find coordinates by given address
 *
 */
function doGeocoding(uid){
	var street = '';
	var zip = '';
	var city = '';
	var country = '';

	// fetch current inputs
	var fieldPrefix = "data[tt_address][" + uid + "]";

	// TYPO3 <= 6.2
	if (document.getElementsByName(fieldPrefix +"[zip]_hr")[0]){

		street =  document.getElementsByName(fieldPrefix + "[address]_hr")[0].value;
		zip =     document.getElementsByName(fieldPrefix + "[zip]_hr")[0].value;
		city =    document.getElementsByName(fieldPrefix + "[city]_hr")[0].value;
		country = document.getElementsByName(fieldPrefix + "[country]_hr")[0].value;
	}
	// TYPO3 >= 7.x
	else if(TYPO3.jQuery
		&& TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[address]\']") ){

		street =  TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[address]\']").val();
		zip =     TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[zip]\']").val();
		city = 	  TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[city]\']").val();
		country = TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[country]\']").val();
	}

	// create gmaps object
	var gmap = new gmaps();

	// associate values to object
	gmap.setAddress(street, zip, city, country);
	// try to fetch coordinates by address, set callback method
	gmap.fetchCoordinatesByAddress(resultsHandling, uid);
}

/**
 * Result handle to check if gecoding was succesfull and display results in backend form
 *
 */
function resultsHandling(latitude, longitude, uid){	
	// work with given results
	if (typeof(latitude) == 'number' && typeof(longitude) == 'number'){

		// write results to backend form
		// var fieldPrefix = "data[tt_content][" + uid + "][pi_flexform][data][sDEF][lDEF]";
		var fieldPrefix = "data[tt_address][" + uid + "]";

		// TYPO3 <= 6.2
		if (document.getElementsByName(fieldPrefix +"[latitude]_hr")[0]) {

			document.getElementsByName(fieldPrefix + "[latitude]_hr")[0].value = latitude;
			document.getElementsByName(fieldPrefix + "[latitude]")[0].value = latitude;
			document.getElementsByName(fieldPrefix + "[longitude]_hr")[0].value = longitude;
			document.getElementsByName(fieldPrefix + "[longitude]")[0].value = longitude;
		}
		// TYPO3 >= 7.x
		else if(TYPO3.jQuery
			&& TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']") ){

			TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']").val(latitude);
			TYPO3.jQuery("input[name*=\'"+ fieldPrefix +"[latitude]\']").val(latitude);
			TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[longitude]\']").val(longitude);
			TYPO3.jQuery("input[name*=\'"+ fieldPrefix +"[longitude]\']").val(longitude);
		}

	} else {
		alert("Die angegebene Adresse konnte nicht lokalisiert werden.");
	}
}

/**
 * Display results in a new windows with coordinates and google maps preview
 *
 */
function displayLocation(uid){
	var latitude = 0;
	var longitude = 0;

	// get coordinates
	// write results to backend form
	var fieldPrefix = "data[tt_address][" + uid + "]";

	// TYPO3 <= 6.2
	if (document.getElementsByName(fieldPrefix +"[latitude]_hr")[0]) {
		latitude  = parseFloat(document.getElementsByName(fieldPrefix +"[latitude]_hr")[0].value);
		longitude = parseFloat(document.getElementsByName(fieldPrefix +"[longitude]_hr")[0].value);
	}
	// TYPO3 >= 7.x
	else if(TYPO3.jQuery
		&& TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']") ){

		latitude = parseFloat(
			TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']").val()
		);
		longitude = parseFloat(
			TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[longitude]\']").val()
		);
	}

	// check if coordinates are given
	if ( typeof(latitude) == 'number' && typeof(longitude) == 'number' ){
        // set attributes to the map
        document.getElementById('cbgm_previewLocation').setAttribute("style", "width:730px; height:500px; border:1px solid #BBBBBB; ", false);

        // create google maps LatLng object
        var latlng = new google.maps.LatLng(latitude, longitude);
        // set options object
        var myOptions = {
			zoom: 14,
			center: latlng,
			mapTypeId: google.maps.MapTypeId.ROADMAP
		};
        // create map
        var map = new google.maps.Map(document.getElementById("cbgm_previewLocation"), myOptions);
        // create map marker
        var marker = new google.maps.Marker({
			position: latlng,
			draggable: true,
			title:""
		});
        // add listener
        google.maps.event.addListener(marker, 'dragend', function() {
            // set new coordinates to the typo3 backend
			var fieldPrefix = "data[tt_address][" + uid + "]";

			// TYPO3 <= 6.2
			if (document.getElementsByName(fieldPrefix +"[latitude]_hr")[0]) {

				document.getElementsByName(fieldPrefix +"[latitude]_hr")[0].value =  marker.getPosition().lat();
				document.getElementsByName(fieldPrefix +"[latitude]")[0].value =  marker.getPosition().lat();

				document.getElementsByName(fieldPrefix +"[latitude]_hr")[0].value =  marker.getPosition().lng();
				document.getElementsByName(fieldPrefix +"[latitude]")[0].value =  marker.getPosition().lng();
			}
			// TYPO3 >= 7.x
			else if(TYPO3.jQuery
				&& TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']") ){

				TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[latitude]\']").val(marker.getPosition().lat());
				TYPO3.jQuery("input[name*=\'"+ fieldPrefix +"[latitude]\']").val(marker.getPosition().lat());
				TYPO3.jQuery("input[data-formengine-input-name*=\'"+ fieldPrefix +"[longitude]\']").val(marker.getPosition().lng());
				TYPO3.jQuery("input[name*=\'"+ fieldPrefix +"[longitude]\']").val(marker.getPosition().lng());
			}
		});

        // assign marker to the map
        marker.setMap(map);

    } else {
        alert("No coordinates or location given.");
    }
}
